/*
 * A demonstration of area filling using different orientations.
 *
 * Copyright (C) 2013 Paul Boddie
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 */

#include "pcf8833.h"
#include <stdio.h>
#include <unistd.h>
#include <signal.h>
#include <stdlib.h>

/**
 * Handle termination of the process.
 */
void shutdown(int signum)
{
    printf("Closing...\n");
    ubb_close(0);
    exit(1);
}

/**
 * Show a pattern on the screen.
 */
void pattern()
{
    LCD_area(0, 0, 131, 131, 0x000);
    LCD_area(21, 21, 35, 65, 0xf800);    LCD_area(21, 66, 35, 110, 0xfbe0);
    LCD_area(36, 21, 50, 65, 0xffe0);    LCD_area(36, 66, 50, 110, 0x7fe0);
    LCD_area(51, 21, 65, 65, 0x07e0);    LCD_area(51, 66, 65, 110, 0x07ef);
    LCD_area(66, 21, 80, 65, 0x07ff);    LCD_area(66, 66, 80, 110, 0x0bff);
    LCD_area(81, 21, 95, 65, 0x001f);    LCD_area(81, 66, 95, 110, 0x781f);
    LCD_area(96, 21, 110, 65, 0xf81f);   LCD_area(96, 66, 110, 110, 0xf80f);
}

uint8_t states[] = {LCD_MADCTL_MY_MX, LCD_MADCTL_MY_V, 0, LCD_MADCTL_MX_V};

int main(int argc, char *argv[])
{
    uint8_t state = 1, times = 10;

    signal(SIGINT, shutdown);

    /* Access the 8:10 port. */

    if (ubb_open(0) < 0) {
        perror("ubb_open");
        return 1;
    }

    ubb_power(1);
    printf("Power on.\n");

    spi_init();
    LCD_init();

    printf("Updating...\n");
    pattern();

    while (times--)
    {
        sleep(1);
        printf("Updating...\n");

        LCD_send(LCD_COMMAND, LCD_MADCTL);
        LCD_send(LCD_DATA, states[state]);
        pattern();

        state = (state + 1) % 4;
    }

    printf("Closing...\n");
    ubb_close(0);
    return 0;
}

/* vim: tabstop=4 expandtab shiftwidth=4
 */
