#!/usr/bin/env python

"""
Produce program files for image data converted to 16bpp values suitable for
writing directly to the display.

Copyright (C) 2013 Paul Boddie

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
"""

import PIL.Image
import math
import sys

def get_image(input_filename, width, height):

    i = PIL.Image.open(input_filename)
    i.thumbnail((width, height), PIL.Image.ANTIALIAS)

    all_values = []
    values = []
    last = None
    x = 0
    for (r, g, b) in i.getdata():
        rgb = ((r >> 3) << 11) | ((g >> 2) << 5) | (b >> 3)
        values.append(rgb)
        x += 1

        if x == width:
            x = 0
            all_values.append(values)
            values = []

    return all_values

def get_image_size(width, height):
    return width * height

if __name__ == "__main__":
    import sys, os

    if len(sys.argv) < 3:
        print sys.argv[0], "<output basename> <image filename>..."
        sys.exit(1)

    output_basename = sys.argv[1]
    input_filenames = sys.argv[2:]
    width = 132
    height = 132
    size = get_image_size(width, height)
    number_of_images = len(input_filenames)

    f = open("%s.c" % output_basename, "wb")

    try:
        # Write the image data.

        f.write("#include <stdint.h>\n")
        f.write("const uint16_t image_data[%d][%d] = {\n" % (number_of_images, size))
        for input_filename in input_filenames:
            f.write("{\n")
            for values in get_image(input_filename, width, height):
                f.write(", ".join([("0x%04x" % v) for v in values]))
                f.write(",\n")
            f.write("},\n")
        f.write("};\n")

    finally:
        f.close()

    f = open("%s.h" % output_basename, "wb")

    try:
        f.write("#include <stdint.h>\n")
        f.write("extern const uint16_t image_data[%d][%d];\n" % (number_of_images, size))
        f.write("#define MAX_IMAGE %d\n" % (number_of_images - 1))
        f.write("#define NUMBER_OF_IMAGES %d\n" % number_of_images)
        f.write("#define IMAGE_SIZE %d\n" % size)
        f.write("#define IMAGE_WIDTH %d\n" % width)
        f.write("#define IMAGE_HEIGHT %d\n" % height)

    finally:
        f.close()

# vim: tabstop=4 expandtab shiftwidth=4
